@@ -1,9 +1,13 @@
 from nonebot.log import logger
 from .chat import Chat, global_chat_dict
 from .persistent_data_manager import PersistentDataManager
-from .Extension import Extension, global_extensions
+from .Extension import Extension, global_extensions, load_extensions
 
 import difflib
+import requests
+import os
+
+from .config import *
 
 # 选项类型  bool只要有就是True，str则需要跟上参数值
 option_type = {
@@ -35,9 +39,8 @@ class CommandManager:
 
     def execute(self, chat:Chat, command:str, chat_presets_dict:dict) -> dict:
         """执行指令"""
-        logger.info('执行指令:' + command)
         option_dict, param_dict, target_route = self.resolve_command(command)
-        logger.info(f'指令匹配路由: {target_route}')
+        logger.info(f'执行命令: "{command}";  指令匹配路由: {target_route}')
         if target_route:
             try:
                 return self.command_router[target_route]['func'](option_dict, param_dict, chat, chat_presets_dict)
@@ -120,7 +123,7 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
                 f"+ 开关会话(管理): rg <on/off> <-global?>\n"
                 f"+ 重置会话(管理): rg <重置/reset> <-global?>\n"
                 f"+ 查询会话(管理): rg <会话/chats>\n"
-                f"+ 拓展信息(管理): rg <拓展/ext>\n"
+                f"+ 扩展信息(管理): rg <扩展/ext>\n"
                 f"Tip: <人格信息> 是一段第三人称的人设说明(建议不超过200字)\n"
             )
         }
@@ -185,11 +188,8 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
     bot_self_introl = param_dict.get('preset_intro', '')
     
     if option_dict.get('global'):   # 全局应用
-        err_cnt = 0
-        for chat_key in global_chat_dict.keys():
-            if not PersistentDataManager.instance.add_preset(chat_key=chat_key, preset_key=target_preset_key, bot_self_introl=bot_self_introl):
-                err_cnt += 1
-        return {'msg': f"添加预设: {target_preset_key} (￣▽￣)-ok! (所有会话) {f'错误:{err_cnt}' if err_cnt else ''}", 'is_progress': True}
+        success_cnt, fail_cnt = PersistentDataManager.instance.add_preset_for_all(preset_key=target_preset_key, bot_self_introl=bot_self_introl)
+        return {'msg': f"添加预设: {target_preset_key} (￣▽￣)-ok! (所有会话) 成功:{success_cnt}，失败:{fail_cnt}", 'is_progress': True}
     elif option_dict.get('target'): # 指定会话应用
         target_chat_key = option_dict.get('target')
         if target_chat_key not in global_chat_dict:
@@ -210,11 +210,9 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
     bot_self_introl = param_dict.get('preset_intro', '')
     
     if option_dict.get('global'):   # 全局应用
-        err_cnt = 0
-        for chat_key in global_chat_dict.keys():
-            if not PersistentDataManager.instance.update_preset(chat_key=chat_key, preset_key=target_preset_key, bot_self_introl=bot_self_introl):
-                err_cnt += 1
-        return {'msg': f"编辑预设: {target_preset_key} (￣▽￣)-ok! (所有会话) {f'错误:{err_cnt}' if err_cnt else ''}", 'is_progress': True}
+        if option_dict.get('global'):   # 全局应用
+            success_cnt, fail_cnt = PersistentDataManager.instance.update_preset_for_all(preset_key=target_preset_key, bot_self_introl=bot_self_introl)
+            return {'msg': f"编辑预设: {target_preset_key} (￣▽￣)-ok! (所有会话) 成功:{success_cnt}，失败:{fail_cnt}", 'is_progress': True}
     elif option_dict.get('target'): # 指定会话应用
         target_chat_key = option_dict.get('target')
         if target_chat_key not in global_chat_dict:
@@ -234,12 +232,9 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
     target_preset_key = param_dict['preset_key']
 
     if option_dict.get('global'):   # 全局应用
-        err_cnt = 0
-        for chat_key in global_chat_dict.keys():
-            if not PersistentDataManager.instance.del_preset(chat_key=chat_key, preset_key=target_preset_key):
-                err_cnt += 1
-        return {'msg': f"删除预设: {target_preset_key} (￣▽￣)-ok! (所有会话) {f'错误:{err_cnt}' if err_cnt else ''}", 'is_progress': True}
-    elif option_dict.get('target'): # 指定会话应用
+        if option_dict.get('global'):   # 全局应用
+            success_cnt, fail_cnt = PersistentDataManager.instance.del_preset_for_all(preset_key=target_preset_key)
+            return {'msg': f"删除预设: {target_preset_key} (￣▽￣)-ok! (所有会话) 成功:{success_cnt}，失败:{fail_cnt}", 'is_progress': True}
         target_chat_key = option_dict.get('target')
         if target_chat_key not in global_chat_dict:
             return {'msg': f"会话: {target_chat_key} 不存在! (；′⌒`)"}
@@ -257,11 +252,9 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
 def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
 
     if option_dict.get('global'):   # 全局应用
-        err_cnt = 0
-        for chat_key in global_chat_dict.keys():
-            if not PersistentDataManager.instance.reset_chat(chat_key=chat_key):
-                err_cnt += 1
-        return {'msg': f"重置 (￣▽￣)-ok! (所有会话) {f'错误:{err_cnt}' if err_cnt else ''}", 'is_progress': True}
+        if option_dict.get('global'):   # 全局应用
+            success_cnt, fail_cnt = PersistentDataManager.instance.reset_chat_for_all()
+            return {'msg': f"重置会话(￣▽￣)-ok! (所有会话) 成功:{success_cnt}，失败:{fail_cnt}", 'is_progress': True}
     elif option_dict.get('target'): # 指定会话应用
         target_chat_key = option_dict.get('target')
         if target_chat_key not in global_chat_dict:
@@ -335,6 +328,52 @@ def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
         ext_info += f"  {ext.generate_short_description()}"
     return {'msg': f"已加载的扩展:\n{ext_info}"}
 
+@cmd.register(route='rg/ext/add', params=['ext_name'])
+def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
+    ext_base_url = "https://raw.githubusercontent.com/KroMiose/nonebot_plugin_naturel_gpt/main/extensions"
+    ext_name:str = param_dict.get('ext_name')
+    if not ext_name:
+        return {'msg': f"未指定扩展名!"}
+    if not ext_name.startswith('ext_'): # 扩展名不以 ext_ 开头则自动补全
+        ext_name = f"ext_{ext_name}"
+    if not ext_name.endswith('.py'):    # 扩展名不以 .py 结尾则自动补全
+        ext_name = f"{ext_name}.py"
+
+    ext_file_path = f"{config.NG_EXT_PATH}{ext_name}"   # 扩展文件存储路径
+    # 从 github 下载扩展
+    try:
+        with open(ext_file_path, 'w') as f:
+            code = requests.get(f"{ext_base_url}/{ext_name}", timeout=10)
+            if code.text.startswith('404: Not Found'):
+                return {'msg': f"下载扩展失败: 未找到扩展 {ext_name}"}
+            f.write(code.text)
+    except Exception as e:
+        return {'msg': f"下载扩展失败: {e}"}
+    return {'msg': f"下载扩展 {ext_name} 成功!"}
+
+@cmd.register(route='rg/ext/del', params=['ext_name'])
+def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
+    ext_name = param_dict.get('ext_name')
+    if not ext_name:
+        return {'msg': f"未指定扩展名!"}
+    if not ext_name.startswith('ext_'): # 扩展名不以 ext_ 开头则自动补全
+        ext_name = f"ext_{ext_name}"
+    if not ext_name.endswith('.py'):    # 扩展名不以 .py 结尾则自动补全
+        ext_name = f"{ext_name}.py"
+
+    ext_file_path = f"{config.NG_EXT_PATH}{ext_name}"   # 扩展文件存储路径
+    # 从本地文件删除扩展
+    try:
+        os.remove(ext_file_path)
+    except Exception as e:
+        return {'msg': f"删除扩展失败: {e}"}
+    return {'msg': f"删除扩展 {ext_name} 成功!"}
+
+@cmd.register(route='rg/ext/reload', params=['ext_name'])
+def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
+    load_extensions(config.dict())
+    return {'msg': f"重载扩展成功!"}
+
 @cmd.register(route='rg/chats')
 def _(option_dict, param_dict, chat:Chat, chat_presets_dict:dict):
     chat_info:str = ''
